PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_custom Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pyx_custom Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_custom:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
int | verbose = 2
str | source_path = ''
str | source_file = 'mcd_astandard'
str | output_file_path = ''
str | base_path = ''
| scratch_path = os.getcwd()
| libs = None
| includes = None
| libpaths = None
str | msvsc = "vs2015"
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Runs an user-defined build process utilizing the PyXMake build environment."
list | user_options

## Protected Member Functions
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _perform_post_actions (self)

## Static Protected Attributes
str | _PACKAGE_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 830 of file stm_make.py.

## Member Function Documentation

## ◆ _run_command()

PyXMake.VTL.stm_make.pyx_custom._run_command | ( |  | self,
|  |  | command )
| protected

    Execute build command

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 883 of file stm_make.py.

## ◆ finalize_options()

PyXMake.VTL.stm_make.pyx_custom.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 872 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pyx_custom.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 849 of file stm_make.py.

## Member Data Documentation

## ◆ _INPUT_FILES

list PyXMake.VTL.stm_make.pyx_custom._INPUT_FILES = []
| staticprotected

Definition at line 835 of file stm_make.py.

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.pyx_custom._PACKAGE_NAME = ''
| staticprotected

Definition at line 834 of file stm_make.py.

## ◆ base_path

PyXMake.VTL.stm_make.pyx_custom.base_path = ''

Definition at line 858 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pyx_custom.description = "Runs an user-defined build process utilizing the PyXMake build environment."
| static

Definition at line 837 of file stm_make.py.

## ◆ includes

PyXMake.VTL.stm_make.pyx_custom.includes = None

Definition at line 861 of file stm_make.py.

## ◆ libpaths

PyXMake.VTL.stm_make.pyx_custom.libpaths = None

Definition at line 862 of file stm_make.py.

## ◆ libs

PyXMake.VTL.stm_make.pyx_custom.libs = None

Definition at line 860 of file stm_make.py.

## ◆ msvsc

str PyXMake.VTL.stm_make.pyx_custom.msvsc = "vs2015"

Definition at line 867 of file stm_make.py.

## ◆ output_file_path

PyXMake.VTL.stm_make.pyx_custom.output_file_path = ''

Definition at line 857 of file stm_make.py.

## ◆ scratch_path

PyXMake.VTL.stm_make.pyx_custom.scratch_path = os.getcwd()

Definition at line 859 of file stm_make.py.

## ◆ source_file

str PyXMake.VTL.stm_make.pyx_custom.source_file = 'mcd_astandard'

Definition at line 856 of file stm_make.py.

## ◆ source_path

PyXMake.VTL.stm_make.pyx_custom.source_path = ''

Definition at line 855 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_custom.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('msvsc=', None, 'identifier, which compiler version from Microsoft Visual Studio to be used'),
('source-path=', None, 'path to the folder holding source files'),
('source-file=', None, 'source file or list of source files. Defaults to "mcd_astandard"'),
('verbose=', None, 'controls the logging level (0 - Nothing) Default: 2 - Everything'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('base-path=', None, 'path to base folder - optional'),
('output-file-path=', None, 'path to the output directory'),
]

Definition at line 838 of file stm_make.py.

## ◆ verbose

int PyXMake.VTL.stm_make.pyx_custom.verbose = 2

Definition at line 854 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py